unit Main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, FileCtrl, ComCtrls, qLstView, qFL, Buttons, ExtCtrls, Menus,
  CommCtrl;

type
  TMainForm = class(TForm)
    FileList: TQuickFileList;
    DirList: TDirectoryListBox;
    DriveCombo: TDriveComboBox;
    ShortLabel: TLabel;
    InfoLabel: TLabel;
    FullLabel: TLabel;
    ViewStylePanel: TPanel;
    LargeIconsBtn: TSpeedButton;
    SmallIconsBtn: TSpeedButton;
    ListBtn: TSpeedButton;
    ReportBtn: TSpeedButton;
    FilePopupMenu: TPopupMenu;
    CopyToItem: TMenuItem;
    MoveToItem: TMenuItem;
    RenameItem: TMenuItem;
    DeleteItem: TMenuItem;
    ShowSelBtn: TButton;
    Label1: TLabel;
    procedure DirListChange(Sender: TObject);
    procedure FileListItemIndexChange(Sender: TObject;
      newItemIndex: Integer);
    procedure FormCreate(Sender: TObject);
    procedure LargeIconsBtnClick(Sender: TObject);
    procedure SmallIconsBtnClick(Sender: TObject);
    procedure ListBtnClick(Sender: TObject);
    procedure ReportBtnClick(Sender: TObject);
    procedure FilePopupMenuPopup(Sender: TObject);
    procedure FileListChange(Sender: TObject; pnmv: PNMListView;
      Change: TItemChange);
    procedure ShowSelBtnClick(Sender: TObject);
    procedure FileListMouseDown(Sender: TObject; Button: TMouseButton;
      Shift: TShiftState; X, Y: Integer);
    procedure FileListMouseUp(Sender: TObject; Button: TMouseButton;
      Shift: TShiftState; X, Y: Integer);
    procedure FileListDblClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
    procedure UpdateCaption;
    procedure EnableFileMenuItems( Value: Boolean );
    function  GetSelectedFileName: string;
  end;

var
  MainForm: TMainForm;

implementation

{$R *.DFM}


function NormPath( Path: string ): string;
begin
  Result := Path;
  if (Result <> '') and (Result[Length(Result)] <> '\') then Result := Result + '\';
end;


procedure TMainForm.FormCreate(Sender: TObject);
begin
  FileList.Directory := DirList.Directory;
  UpdateCaption;

  //Here you can change file list header
  FileList.ColumnText[clName] := 'Name';
  FileList.ColumnText[clSize] := 'Size';
  FileList.ColumnText[clType] := 'Type';
  FileList.ColumnText[clDate] := 'Date';
end;


procedure TMainForm.DirListChange(Sender: TObject);
begin
  FileList.Directory := DirList.Directory;
  UpdateCaption;  
end;


procedure TMainForm.UpdateCaption;
begin
  Caption := 'QuickFileList Example - ' + DirList.Directory;
end;


procedure TMainForm.FileListItemIndexChange(Sender: TObject;
  newItemIndex: Integer);
var
  Idx: Integer;
  //or ......
  //FileInfo: TqFileData;
  Msg: string;
begin
  Idx := FileList.ItemIndex;
  if Idx <> -1 then
  begin
    if FileList.IsDirectory(Idx) then
    //or .....
    //FileInfo := FileList.FileItem[Idx];
    //if (FileInfo.dwFileAttributes and FILE_ATTRIBUTE_DIRECTORY) > 0 then
      Msg := 'DirName:'
    else
      Msg := 'FileName:';
  end;
  InfoLabel.Caption  := Msg;
  ShortLabel.Caption := FileList.FileName;
  FullLabel.Caption  := FileList.Directory + FileList.FileName;
end;


procedure TMainForm.LargeIconsBtnClick(Sender: TObject);
begin
  FileList.ViewStyle := vsIcon;
end;


procedure TMainForm.SmallIconsBtnClick(Sender: TObject);
begin
  FileList.ViewStyle := vsSmallIcon;
end;


procedure TMainForm.ListBtnClick(Sender: TObject);
begin
  FileList.ViewStyle := vsList;
end;


procedure TMainForm.ReportBtnClick(Sender: TObject);
begin
  FileList.ViewStyle := vsReport;
end;


procedure TMainForm.FilePopupMenuPopup(Sender: TObject);
begin
  EnableFileMenuItems( GetSelectedFileName <> '' );
end;


procedure TMainForm.EnableFileMenuItems( Value: Boolean );
begin
  CopyToItem.Enabled := Value;
  MoveToItem.Enabled := Value;
  RenameItem.Enabled := Value;
  DeleteItem.Enabled := Value;
end;


function TMainForm.GetSelectedFileName: string;
var
  FullFileName: string;
begin
  Result := '';
  if FileList.ItemIndex <> -1 then
  begin
    FullFileName := FileList.Directory + FileList.FileName;
    if FileExists( FullFileName ) then
      Result := FullFileName;
  end;
end;


procedure TMainForm.FileListChange(Sender: TObject; pnmv: PNMListView;
  Change: TItemChange);
begin
  //
end;


procedure TMainForm.ShowSelBtnClick(Sender: TObject);
var
  I: Integer;
  Msg: string;
begin
  Msg := '';
  for I:=0 to FileList.Count do
    if FileList.Selected[I] then
      Msg := Msg + FileList.FileItem[I].sFileName + '  ';
  ShowMessage(Msg);
end;


procedure TMainForm.FileListMouseDown(Sender: TObject;
  Button: TMouseButton; Shift: TShiftState; X, Y: Integer);
begin
  //
end;


procedure TMainForm.FileListMouseUp(Sender: TObject; Button: TMouseButton;
  Shift: TShiftState; X, Y: Integer);
begin
  //
end;


procedure TMainForm.FileListDblClick(Sender: TObject);
var
  Path: string;
begin
  //
  if FileList.IsDirectory(FileList.ItemIndex) then
  begin
    Path := NormPath(FileList.Directory + FileList.FileName);
    DirList.Directory := Path;
  end;
end;

end.
